@@ -1424,10 +1424,15 @@ impl App {
             last_modes: Default::default(),
         };
 
+        let has_errs = !load_errs.is_empty();
         for err in load_errs {
             app = app.log_error(err)?
         }
 
+        if has_errs && !app.config.general.disable_debug_error_mode {
+            app = app.switch_mode_builtin("debug_error")?;
+        }
+
         Ok(app)
     }
 
@@ -2672,6 +2677,7 @@ impl App {
 
         [
             &builtin.default,
+            &builtin.debug_error,
             &builtin.recover,
             &builtin.filter,
             &builtin.number,
